@@ -26,8 +26,8 @@ Panel Sharing was made with Panel! Check out the code and **report issues
 ).servable()
 
 pn.state.template.param.update(
-    site="Panel Sharing",
-    title="Welcome",
-    site_url="https://github.com/awesome-panel/panel-sharing",
+    site="Awesome Panel Sharing",
+    site_url="https://awesome-panel.org/sharing",
     favicon="https://raw.githubusercontent.com/MarcSkovMadsen/awesome-panel-assets/320297ccb92773da099f6b97d267cc0433b67c23/favicon/ap-1f77b4.ico",
+    title="Welcome",
 )
